package jdk.javadoc.internal.tool.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "24.0.1+9-jvmci-b01" },
            { "jdk", "24.0.1" },
            { "release", "24.0.1" },
        };
    }
}
